#MagCalibration

This is a program to calibrate the effective pixel size for cryoEM data collected on gold foils.
Documentation and source code is availbale at www.mrc-lmb.cam.ac.uk/crusso/
If the program is useful in your work, please cite: 
Joshua L. Dickerson, Erin Leahy, Mathew J. Peet, Katerina Naydenova, Christopher J. Russo. "Accurate magnification determination for cryoEM using gold". Ultramicroscopy 2023:113883.


